@@ -49,6 +49,8 @@ class Links(Resource):
         username: str,
         password: str,
         *,
+        username2: str = None,
+        password2: str = None,
         token: str = None,
         encryption_key: str = None,
         save_data: bool = True,
@@ -70,6 +72,12 @@ class Links(Resource):
             "access_mode": access_mode.value,
         }
 
+        if username2:
+            data.update(username2=username2)
+
+        if password2:
+            data.update(password2=password2)
+
         if token:
             data.update(token=token)
 
@@ -127,6 +135,14 @@ class Links(Resource):
 
         return self.session.put(self.endpoint, id=link, data=data, raise_exception=raise_exception)
 
+    def token(
+        self, link: str, scopes: str, *, raise_exception: bool = False
+    ) -> Union[List[Dict], Dict]:
+        data = {"scopes": scopes}
+        return self.session.post(
+            f"{self.endpoint}{link}/token/", data=data, raise_exception=raise_exception
+        )
+
 
 class Accounts(Resource):
     endpoint = "/api/accounts/"
@@ -139,7 +155,7 @@ class Accounts(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         data = {"link": link, "save_data": save_data}
@@ -168,7 +184,7 @@ class Transactions(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         if date_to is None:
@@ -202,7 +218,7 @@ class Balances(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         if date_to is None:
@@ -222,6 +238,46 @@ class Balances(Resource):
         )
 
 
+class Incomes(Resource):
+    endpoint = "/api/incomes/"
+
+    def create(
+        self,
+        link: str,
+        *,
+        token: str = None,
+        encryption_key: str = None,
+        save_data: bool = True,
+        raise_exception: bool = False,
+        **kwargs: Dict,
+    ) -> Union[List[Dict], Dict]:
+
+        data = {"link": link, "save_data": save_data}
+
+        if token:
+            data.update(token=token)
+        if encryption_key:
+            data.update(encryption_key=encryption_key)
+
+        return self.session.post(
+            self.endpoint, data=data, raise_exception=raise_exception, **kwargs
+        )
+
+    def list(self, **kwargs) -> Generator:
+        raise NotImplementedError()
+
+    def get(self, id: str, **kwargs) -> Dict:
+        raise NotImplementedError()
+
+    def delete(self, id: str) -> bool:
+        raise NotImplementedError()
+
+    def resume(
+        self, session: str, token: str, *, link: str = None, raise_exception: bool = False, **kwargs
+    ) -> Union[List[Dict], Dict]:
+        raise NotImplementedError()
+
+
 class Institutions(Resource):
     endpoint = "/api/institutions/"
 
@@ -235,7 +291,7 @@ class Institutions(Resource):
         *,
         link: str = None,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Dict:
         raise NotImplementedError()
 
@@ -251,7 +307,7 @@ class Owners(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         data = {"link": link, "save_data": save_data}
@@ -280,7 +336,7 @@ class Invoices(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         data = {
@@ -306,7 +362,7 @@ class Invoices(Resource):
         *,
         link: str = None,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Dict:
         raise NotImplementedError()
 
@@ -324,7 +380,7 @@ class TaxReturns(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         if year_to is None:
@@ -352,7 +408,7 @@ class TaxReturns(Resource):
         *,
         link: str = None,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Dict:
         raise NotImplementedError()
 
@@ -368,7 +424,7 @@ class TaxStatus(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         data = {"link": link, "attach_pdf": attach_pdf, "save_data": save_data}
@@ -387,7 +443,7 @@ class TaxStatus(Resource):
         *,
         link: str = None,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Dict:
         raise NotImplementedError()
 
@@ -406,7 +462,7 @@ class Statements(Resource):
         encryption_key: str = None,
         save_data: bool = True,
         raise_exception: bool = False,
-        **kwargs: str,
+        **kwargs: Dict,
     ) -> Union[List[Dict], Dict]:
 
         data = {
